@@ -16,6 +16,14 @@ from praw.util.token_manager import BaseTokenManager
 from . import UnitTest
 
 
+class DummyTokenManager(BaseTokenManager):
+    def post_refresh_callback(self, authorizer):
+        pass
+
+    def pre_refresh_callback(self, authorizer):
+        pass
+
+
 class TestReddit(UnitTest):
     REQUIRED_DUMMY_SETTINGS = {
         x: "dummy" for x in ["client_id", "client_secret", "user_agent"]
@@ -202,8 +210,8 @@ class TestReddit(UnitTest):
     def test_read_only__with_authenticated_core(self):
         with Reddit(
             password=None,
-            token_manager=BaseTokenManager(),
             username=None,
+            token_manager=DummyTokenManager(),
             **self.REQUIRED_DUMMY_SETTINGS,
         ) as reddit:
             assert not reddit.read_only
@@ -230,8 +238,8 @@ class TestReddit(UnitTest):
             client_id="dummy",
             client_secret=None,
             redirect_uri="dummy",
-            token_manager=BaseTokenManager(),
             user_agent="dummy",
+            token_manager=DummyTokenManager(),
         ) as reddit:
             assert not reddit.read_only
             reddit.read_only = True
@@ -318,7 +326,7 @@ class TestReddit(UnitTest):
 
     @mock.patch("prawcore.sessions.Session")
     def test_request__badrequest_with_no_json_body(self, mock_session):
-        response = mock.Mock(status_code=400)
+        response = mock.Mock(status_code=400, text="")
         response.json.side_effect = ValueError
         mock_session.return_value.request = mock.Mock(
             side_effect=BadRequest(response=response)
@@ -327,7 +335,7 @@ class TestReddit(UnitTest):
         reddit = Reddit(client_id="dummy", client_secret="dummy", user_agent="dummy")
         with pytest.raises(Exception) as excinfo:
             reddit.request("POST", "/")
-        assert str(excinfo.value).startswith("Unexpected BadRequest without json body.")
+        assert str(excinfo.value) == "received 400 HTTP response"
 
     def test_request__json_and_body(self):
         reddit = Reddit(client_id="dummy", client_secret="dummy", user_agent="dummy")
